@@ -1,7 +1,7 @@
 package HTML::TreeBuilder::LibXML;
 use strict;
 use warnings;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 use Carp ();
 use base 'HTML::TreeBuilder::LibXML::Node';
 use XML::LibXML;
@@ -11,6 +11,24 @@ sub new {
     bless {}, $class;
 }
 
+sub new_from_content {
+    my $class = shift;
+    my $self  = $class->new;
+    for my $content (@_) {
+        $self->parse($content);
+    }
+    $self->eof;
+
+    return $self;
+}
+
+sub new_from_file {
+    my $class = shift;
+    my $self  = $class->new;
+    $self->parse_file(@_);
+    return $self;
+}
+
 my $PARSER;
 sub _parser {
     unless ($PARSER) {
@@ -29,6 +47,12 @@ sub parse {
     $self->{_content} .= $html;
 }
 
+sub parse_file {
+    my $self = shift;
+    my $doc  = $self->_parser->parse_html_file(@_);
+    $self->{node} = $doc->documentElement;
+}
+
 sub eof {
     my ($self, ) = @_;
     my $doc = $self->_parser->parse_html_string($self->{_content});
